/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb;

import java.io.File;
import java.io.IOException;
import java.security.Policy;

import org.apache.openejb.config.DeploymentModule;

public interface OpenEJBCoreController {

    Policy getPolicy();

    AppModuleCreatorData createAppModule(File jarFile, ClassLoader parentClassLoader) throws OpenEJBException;

    WebModuleCreatorData createWebModule(File warFile, ClassLoader parentClassLoader) throws OpenEJBException;

    Class<? extends DeploymentModule> getModuleClass(File jarFile);

    String removeExtension(String name);

    void setPolicy(Policy policy);

    boolean extract(File file, File destinationDir) throws IOException;

    File getUnpackDir(File file);

    boolean filterApplication(String name);

    ClassLoader createAppSharedLoader(ClassLoader parent);

    void associateWithWar(Object alreadyAssociated, Object toAssociate);

    void associateWithThreadWar(Object toAssociate);

    void unsetThreadWar();

}
